# Allen Institute Contribution Agreement

This document describes the terms under which you may make “Contributions” — 
which may include without limitation, software additions, revisions, bug fixes, configuration changes,
documentation, or any other materials — to any of the projects owned or managed by the Allen Institute.
If you have questions about these terms, please contact us at terms@alleninstitute.org.  

You certify that:

•	Your Contributions are either:

1.	Created in whole or in part by you and you have the right to submit them under the designated license 
(described below); or
2.	Based upon previous work that, to the best of your knowledge, is covered under an appropriate 
open source license and you have the right under that license to submit that work with modifications,
whether created in whole or in part by you, under the designated license; or

3.	Provided directly to you by some other person who certified (1) or (2) and you have not modified them.

•	You are granting your Contributions to the Allen Institute under the terms of the [2-Clause BSD license](https://opensource.org/licenses/BSD-2-Clause)
(the “designated license”).

•	You understand and agree that the Allen Institute projects and your Contributions are public and that 
a record of the Contributions (including all metadata and personal information you submit with them) is 
maintained indefinitely and may be redistributed consistent with the Allen Institute’s mission and the 
2-Clause BSD license.  
